@@ -18,8 +18,11 @@ class JournalMiddleware(object):
                     user=user, ip=ip, **kwargs)
         request.record = record
         request.error_record = error_record
+        return None
 
     def process_response(self, request, response):
-        del request.record
-        del request.error_record
+        if hasattr(request, 'record'):
+            del request.record
+        if hasattr(request, 'error_record'):
+            del request.error_record
         return response
